==> pyEthioNews-1.0.0.tar.gz: pyEthioNews-1.0.0/README.md <==
#   p y E t h i o N e w s A p i 
 
 
 
 T h i s   i s   a   p y t h o n   w r a p p e r   f o r   t h e   E t h i o p i a n   n e w s   w e b s i t e s   [ V o a   A m h a r i c ] ( h t t p s : / / a m h a r i c . v o a n e w s . c o m / ) ,   [ F a n a b c ] ( h t t p s : / / w w w . f a n a b c . c o m / ) ,   [ M e r e j a ] ( h t t p s : / / m e r e j a . c o m / ) ,   [ W a l t a I n f o ] ( h t t p s : / / w a l t a i n f o . c o m / ) 
 
 
 
 # #   I n s t a l l a t i o n 
 
 
 
 ` ` ` b a s h 
 
 p i p   i n s t a l l   g i t + h t t p s : / / g i t h u b . c o m / w i z k i y e / p y E t h i o N e w s A p i . g i t 
 
 ` ` ` 
 
 
 
 # #   U s a g e 
 
 
 
 ` ` ` p y t h o n 
 
 f r o m   p y E t h i o N e w s . p r o v i d e r s   i m p o r t   V O A A m h a r i c ,   F a n a B c ,   M e r e j a ,   W a l t a 
 
 
 
 
 
 a s y n c   d e f   m a i n ( ) : 
 
         #   G e t   l a t e s t   n e w s 
 
         
 
         v o a   =   V O A A m h a r i c ( ) 
 
         f a n a   =   F a n a B c ( ) 
 
         m e r e j a   =   M e r e j a ( ) 
 
         w a l t a   =   W a l t a ( ) 
 
 
 
         v o a _ l a t e s t   =   a w a i t   v o a . g e t _ w o r l d _ w i d e _ n e w s ( ) 
 
         f a n a _ l a t e s t   =   a w a i t   f a n a . g e t _ m a i n _ n e w s ( ) 
 
         m e r e j a _ l a t e s t   =   a w a i t   m e r e j a . g e t _ n e w s ( ) 
 
         w a l t a _ l a t e s t   =   a w a i t   w a l t a . g e t _ w o r l d _ w i d e _ n e w s ( ) 
 
 
 
         p r i n t ( v o a _ l a t e s t [ 0 ] . t i t l e ) 
 
         p r i n t ( f a n a _ l a t e s t [ 0 ] . t i t l e ) 
 
         p r i n t ( m e r e j a _ l a t e s t [ 0 ] . t i t l e ) 
 
         p r i n t ( w a l t a _ l a t e s t [ 0 ] . t i t l e ) 
 
 
 
 ` ` ` 

==> pyEthioNews-1.0.2.tar.gz: pyEthioNews-1.0.2/README.md <==
#   p y E t h i o N e w s A p i 
 
 
 
 T h i s   i s   a   p y t h o n   w r a p p e r   f o r   t h e   E t h i o p i a n   n e w s   w e b s i t e s   [ V o a   A m h a r i c ] ( h t t p s : / / a m h a r i c . v o a n e w s . c o m / ) ,   [ F a n a b c ] ( h t t p s : / / w w w . f a n a b c . c o m / ) ,   [ M e r e j a ] ( h t t p s : / / m e r e j a . c o m / ) ,   [ W a l t a I n f o ] ( h t t p s : / / w a l t a i n f o . c o m / ) 
 
 
 
 # #   I n s t a l l a t i o n 
 
 
 
 ` ` ` b a s h 
 
 p i p   i n s t a l l   g i t + h t t p s : / / g i t h u b . c o m / w i z k i y e / p y E t h i o N e w s A p i . g i t 
 
 ` ` ` 
 
 
 
 # #   U s a g e 
 
 
 
 ` ` ` p y t h o n 
 
 f r o m   p y E t h i o N e w s . p r o v i d e r s   i m p o r t   V O A A m h a r i c ,   F a n a B c ,   M e r e j a ,   W a l t a 
 
 
 
 
 
 a s y n c   d e f   m a i n ( ) : 
 
         #   G e t   t h e   l a t e s t   n e w s 
 
         
 
         v o a   =   V O A A m h a r i c ( ) 
 
         f a n a   =   F a n a B c ( ) 
 
         m e r e j a   =   M e r e j a ( ) 
 
         w a l t a   =   W a l t a ( ) 
 
 
 
         v o a _ l a t e s t   =   a w a i t   v o a . g e t _ w o r l d _ w i d e _ n e w s ( ) 
 
         f a n a _ l a t e s t   =   a w a i t   f a n a . g e t _ m a i n _ n e w s ( ) 
 
         m e r e j a _ l a t e s t   =   a w a i t   m e r e j a . g e t _ n e w s ( ) 
 
         w a l t a _ l a t e s t   =   a w a i t   w a l t a . g e t _ w o r l d _ w i d e _ n e w s ( ) 
 
 
 
         p r i n t ( v o a _ l a t e s t [ 0 ] . t i t l e ) 
 
         p r i n t ( f a n a _ l a t e s t [ 0 ] . t i t l e ) 
 
         p r i n t ( m e r e j a _ l a t e s t [ 0 ] . t i t l e ) 
 
         p r i n t ( w a l t a _ l a t e s t [ 0 ] . t i t l e ) 
 
 
 
 ` ` ` 
